### Name: isSubmodel
### Title: Is the CURRENT model a sub model of the BASE model ?
### Aliases: isSubmodel
### Keywords: methods multivariate

### ** Examples

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE, 
         object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

.set.switch(26921, "on");
.set.switch(26931, "on");
.set.switch(11081, "on");
.set.switch(11071, "on");
.set.switch(11061, "on");
.set.switch(6301, "on");

isSubmodel(object = CoCoObject); # TRUE
isSubmodel(1, 4, object = CoCoObject); # FALSE
isSubmodel(4, 1, object = CoCoObject); # TRUE

homogeneModel <- makeModel(enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]",
                           object = CoCoObject));

# Numbers:

n6 <- returnModelNumber(homogeneModel, object = CoCoObject);

isSubmodel(object = CoCoObject); # TRUE
isSubmodel(1, n6, object = CoCoObject); # FALSE
isSubmodel(n6, 1, object = CoCoObject); # TRUE

# Text string with tags:

isSubmodel("base", "current", object = CoCoObject); # FALSE
isSubmodel("current", "base", object = CoCoObject); # TRUE
isSubmodel("last", "base", object = CoCoObject); # TRUE

# Objects:

isSubmodel(fullModel, homogeneModel, object = CoCoObject); # FALSE
isSubmodel(homogeneModel, fullModel, object = CoCoObject); # TRUE

# Non existing models:

isSubmodel("current", 7, object = CoCoObject); # NULL
isSubmodel(7, "base", object = CoCoObject); # NULL

makeCurrent(7, object = CoCoObject);
isSubmodel(1, 4, object = CoCoObject); # FALSE
isSubmodel(4, 1, object = CoCoObject); # TRUE

showModel("all", object = CoCoObject);

makeCurrent(4, object = CoCoObject);
isSubmodel("next", "base", object = CoCoObject); # Using current!
isSubmodel("previous", "base", object = CoCoObject); #  Using current!

# Text string with generating class:

isSubmodel("aby", object = CoCoObject); # TRUE
isSubmodel("ab", "a,b", object = CoCoObject); # FALSE

enterModel("ab", object = CoCoObject);
isSubmodel("aby", object = CoCoObject); # TRUE: Sub model of base!!!!
makeBase(, object = CoCoObject);
isSubmodel("aby", object = CoCoObject); # FALSE

endCoCo(object = CoCoObject);



